pub struct ServerName {
pub typ: ServerNameType,
pub payload: ServerNamePayload,
}Fields
typ: ServerNameTypepayload: ServerNamePayloadTrait Implementations
sourceimpl Clone for ServerName
impl Clone for ServerName
sourcefn clone(&self) -> ServerName
fn clone(&self) -> ServerName
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Codec for ServerName
impl Codec for ServerName
sourcefn encode(&self, bytes: &mut Vec<u8>)
fn encode(&self, bytes: &mut Vec<u8>)
Function for encoding itself by appending itself to
the provided vec of bytes. Read more
sourcefn read(r: &mut Reader<'_>) -> Option<Self>
fn read(r: &mut Reader<'_>) -> Option<Self>
Function for decoding itself from the provided reader
will return Some if the decoding was successful or
None if it was not. Read more
sourcefn get_encoding(&self) -> Vec<u8>
fn get_encoding(&self) -> Vec<u8>
Convenience function for encoding the implementation
into a vec and returning it Read more
sourcefn read_bytes(bytes: &[u8]) -> Option<Self>
fn read_bytes(bytes: &[u8]) -> Option<Self>
Function for wrapping a call to the read function in
a Reader for the slice of bytes provided Read more